@@ -10,35 +10,38 @@
 /*
    Title: NASPRO Bridge it
 
-   *Version*: 0.2.91, *API*: 1.0.1.
+   *Version*: 0.3.0, *API*: 2.0.0.
 
    About:
 
-     A little helper library to develop <insert-your-API-here> to LV2 bridges.
+     <NASPRO Bridge it at http://naspro.atheme.org/libraries/naspro-bridge-it/>
+     is a little helper library to develop <insert-your-API-here> to LV2 bridges.
 
      As of now, it basically offers a few utility functions and Turtle/RDF
      serialization for LV2 dynamic manifest generation, supporting the following
      LV2 specifications/extensions.
 
-       * <LV2 at http://lv2plug.in/ns/lv2core> revision 4.0;
-       * <LV2 Dynamic Manifest at http://lv2plug.in/ns/ext/dyn-manifest>
-         revision 1.0;
+       * <LV2 at http://lv2plug.in/ns/lv2core> version 4.0;
+       * <LV2 Dynamic Manifest at http://lv2plug.in/ns/ext/dyn-manifest> version
+         1.0;
+       * <LV2 Port Properties at http://lv2plug.in/ns/ext/port-props> version
+         0.1 (only for the logarithmic port property);
        * <Extended Port Information at http://lv2plug.in/ns/dev/extportinfo>
-         draft revision 3 (only for the logarithmic port property);
-       * <LV2 Events at http://lv2plug.in/ns/ext/event> revision 1.0;
-       * <LV2 MIDI Events at http://lv2plug.in/ns/ext/midi> revision 1.0.
-
-     It is written in C99 and is almost entirely reentrant and thread-safe.
+         draft revision 3 (only for the logarithmic port property, deprecated);
+       * <LV2 Events at http://lv2plug.in/ns/ext/event> version 1.0;
+       * <LV2 MIDI Events at http://lv2plug.in/ns/ext/midi> version 1.0;
+       * <LV2 Presets at http://lv2plug.in/ns/ext/presets> version 2.2.
 
    Supported platforms/compilers:
 
-     There is no platform- or compiler-specific code, hence wherever
-     <NASPRO core at http://naspro.atheme.org/naspro-core/> runs, this library
-     is able to run.
+     It is written in C99 and there is no platform- or compiler-specific code,
+     hence wherever <NASPRO core at http://naspro.atheme.org/naspro-core/> runs,
+     this library is able to run.
 
    API conventions:
 
-     * All functions are thread-safe and reentrant, unless otherwise specified;
+     * No function should be assumed to be thread-safe, unless otherwise
+       specified;
      * All strings are null-terminated and UTF-8 encoded according to the
        Unicode 6.0 standard and without BOM (byte-order-mark) characters, unless
        otherwise specified;
@@ -47,7 +50,8 @@
 
    Runtime dependencies:
 
-     * <NASPRO core at http://naspro.atheme.org/naspro-core/> >= 0.2.91.
+     * <NASPRO core at http://naspro.atheme.org/libraries/naspro-core/> >=
+       0.3.0.
 
    Build-time dependencies:
 
@@ -65,7 +69,7 @@
 
       Just include <NASPRO/brit/lib.h> in your source files and use the
       pkg-config tool to retrieve compiler and linker flags (package name:
-      nabrit-1).
+      nabrit-2).
  */
 
 #ifndef _NASPRO_BRIDGE_IT_LIB_H
@@ -87,7 +91,7 @@
 #include <NASPRO/brit/pluglib.h>
 #include <NASPRO/brit/plugin.h>
 #include <NASPRO/brit/port.h>
-/* #include <NASPRO/brit/preset.h> */
+#include <NASPRO/brit/preset.h>
 #include <NASPRO/brit/manifest.h>
 #include <NASPRO/brit/util.h>
 
