@@ -48,7 +48,8 @@ nabrit_manifest_print_subjects(nabrit_bridge bridge, FILE *fp);
 
    Returns:
 
-     0 on success or ENOENT if the specified subject URI is unknown.
+     0 on success, ENOMEM if there was not enough memory or ENOENT if the
+     specified subject URI is unknown.
  */
 _NABRIT_DEF int
 nabrit_manifest_print_data(nabrit_bridge bridge, FILE *fp, const char *URI);
