@@ -13,12 +13,14 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <math.h>
+
 #include <NASPRO/brit/lib.h>
 
 #include "bridge.h"
 #include "pluglib.h"
 #include "plugin.h"
 #include "port.h"
-/* #include "preset.h" */
+#include "preset.h"
 
 #endif
