@@ -23,7 +23,7 @@ struct _nabrit_port
 	char			 logarithmic;
 	float			 min;
 	float			 max;
-	float			 def;
+	float			 deflt;
   };
 
 NACORE_PRIVATE size_t
